DesignSpark.ESDK
================

.. image:: https://raw.githubusercontent.com/DesignSparkRS/DesignSpark.ESDK/main/docs/images/DesignSpark_ESDK_Library.png
   :alt: Logo

DesignSpark Python library to support the Environmental Sensing Development Kit hardware.

Features include:

* Simple interface to supported ESDK modules
* Support for plugins to extend the ecosystem with new sensors
* Control over mainboard features including buzzer, sensor power rails and GPS

Supported Modules
-----------------

Currently supported sensor modules include:

* ESDK-THV (temperature, humidity and VOC)
* ESDH-CO2 (CO2)
* ESDK-PM2 (PM1.0, PM2.5, PM4.0 and PM10 particulates)
* ESDK-NO2 (NO2)
* ESDK-NRD (nuclear radiation)
* ESDK-FDH (formaldehyde)

Installation
------------

DesignSpark.ESDK can be installed from PyPI using the command-line tool `pip`. See the documentation for more information.

Documentation
-------------

Installation, API documentation and examples are available at:

https://docs.designspark.io/projects/esdk-library/en/latest/index.html
